@@ -101,9 +101,9 @@ class DistributionSheet(Sheet):
         if cell_value_type is DistributionCellValueType.TEXT:
             self.distribution_data.blocks.append(
                 DataBlock(
-                    text=[
+                    text_lines=[
                         TextLine(
-                            text=self.sheet_reader.read_cell(
+                            text_lines=self.sheet_reader.read_cell(
                                 row=row_index,
                                 col=col_index,
                             ).value
