@@ -8,8 +8,8 @@ from xlsx_lib.domain.frame.frame_element import FrameElement
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
 
 from xlsx_lib.domain.frame.complex_frame_element_error import ComplexFrameElementError
-from xlsx_lib.domain.xlsx_elements.errors.empty_value_error import EmptyValueError
-from xlsx_lib.domain.xlsx_elements.errors.sheet_end_error import SheetEndError
+from xlsx_lib.domain.xlsx_elements.exceptions.continue_exception import ContinueException
+from xlsx_lib.domain.xlsx_elements.exceptions.sheet_end_exception import SheetEndException
 
 
 def get_frame_cell_value_type(cell: Cell) -> FrameCellValueTypes:
@@ -52,13 +52,13 @@ class FrameSheet(Sheet):
 
             try:
                 self.process_cell(cell, col_index, row_index)
-            except EmptyValueError:
+            except ContinueException:
                 row_index += 1
                 continue
             except ComplexFrameElementError as error:
                 row_index += error.jumped_rows
                 continue
-            except SheetEndError:
+            except SheetEndException:
                 break
 
             row_index += 1
@@ -76,7 +76,7 @@ class FrameSheet(Sheet):
 
             self.check_next_values(row=row_index)
 
-            raise EmptyValueError
+            raise ContinueException
 
         cell_value_type = get_frame_cell_value_type(cell)
 
@@ -163,4 +163,4 @@ class FrameSheet(Sheet):
                                            is FrameCellValueTypes.FRAME_ELEMENT])
 
         if frame_elements_matches == 0 and element_parts_matches == 0:
-            raise SheetEndError
+            raise SheetEndException
